==> unicore-ucc6-5.0.0-1.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestActionBase.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Map;
import java.util.Properties;

import org.apache.commons.cli.BasicParser;
import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.Options;
import org.junit.Test;

import de.fzj.unicore.uas.security.ClientProperties;
import de.fzj.unicore.ucc.Constants;
import de.fzj.unicore.ucc.UCC;
import de.fzj.unicore.wsrflite.security.ISecurityProperties;
import eu.unicore.bugsreporter.annotation.RegressionTest;
import eu.unicore.security.util.client.HttpUtils;
import eu.unicore.security.util.client.IClientProperties;

public class TestActionBase {

	@Test
	public void testConfigureHandlers()throws Exception{
		Properties p=new Properties();
		p.put(ISecurityProperties.UAS_OUTHANDLER_NAME,"Test123 Test345");
		p.put("Test123.foo", "foo_value");
		p.put("Test123.bar", "bar_value");
		p.put("Test345.ham", "ham_value");
		p.put("Test345.spam", "spam_value");
		p.put("keystore", "src/test/resources/certs/user-keystore.jks");
		p.put("password", "the!user");
		
		final CommandLine cl=new BasicParser().parse(new Options(), new String[0]);
		ActionBase b=new ActionBase(){
			@Override
			public CommandLine getCommandLine() {
				return cl;
			}
		};
		
		b.setProperties(p);
		b.initSecurityProperties();
		ClientProperties sp=(ClientProperties)b.securityProperties;
		assertEquals("foo_value",sp.getProperty("foo"));
		assertEquals("bar_value",sp.getProperty("bar"));
		assertEquals("ham_value",sp.getProperty("ham"));
		assertEquals("spam_value",sp.getProperty("spam"));
		
		assertTrue(sp.getProperty(ISecurityProperties.UAS_OUTHANDLER_NAME).contains("Test123"));
		assertTrue(sp.getProperty(ISecurityProperties.UAS_OUTHANDLER_NAME).contains("Test345"));
	}
	

	@RegressionTest(url="https://sourceforge.net/tracker/?func=detail&aid=3371018&group_id=102081&atid=633902")
	@Test
	public void testTimeoutParameters()throws Exception{
		ActionBase cmd=(ActionBase)UCC.initCommand(new String[]{"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded"},false);
		cmd.initSecurityProperties();
		IClientProperties cp=cmd.getClientProperties();
		assertTrue(cp.getExtraSettings().containsKey(HttpUtils.SO_TIMEOUT));
		assertTrue(cp.getExtraSettings().containsKey(HttpUtils.CONNECT_TIMEOUT));
	}

	@Test
	public void testSecurityPreferencesParsing() throws Exception {
		ActionBase cmd=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "vo:/someVo",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "role:someRole",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "uid:someUid",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "pgid:someGid",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "useOSgids:false",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "supgids:someSupGid1,someSupGid2",
				}, false);
		verifyCommandPref(cmd);

		ActionBase cmd2=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "vo:/someVo",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "role:someRole",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "uid:someUid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "pgid:someGid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "useOSgids:false",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "supgids:someSupGid1,someSupGid2",
				}, false);
		verifyCommandPref(cmd2);

		ActionBase cmd3=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=vo:/someVo",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=role:someRole",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=uid:someUid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=pgid:someGid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=useOSgids:false",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=supgids:someSupGid1,someSupGid2",
				}, false);
		verifyCommandPref(cmd3);
		
		ActionBase cmd4=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs-withSecPrefs.embedded"
				}, false);
		verifyCommandPref(cmd4);
	}
	
	private void verifyCommandPref(ActionBase cmd) throws Exception {
		cmd.initSecurityProperties();
		Map<String, String[]> pref = cmd.getClientProperties().getETDSettings().getRequestedUserAttributes2();
		assertEquals("/someVo", pref.get("selectedVirtualOrganisation")[0]);
		assertEquals("someRole", pref.get("role")[0]);
		assertEquals("someUid", pref.get("xlogin")[0]);
		assertEquals("someGid", pref.get("group")[0]);
		assertEquals("false", pref.get("addDefaultGroups")[0]);
		assertEquals("someSupGid1", pref.get("supplementaryGroups")[0]);
		assertEquals("someSupGid2", pref.get("supplementaryGroups")[1]);
	}
}

==> unicore-ucc6-6.0.0-0.src.tar.gz: ucc-core/src/test/java/de/fzj/unicore/ucc/actions/TestActionBase.java <==
package de.fzj.unicore.ucc.actions;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.util.Map;
import java.util.Properties;

import org.apache.commons.cli.BasicParser;
import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.Options;
import org.junit.Ignore;
import org.junit.Test;

import de.fzj.unicore.ucc.Constants;
import de.fzj.unicore.ucc.UCC;
import eu.unicore.bugsreporter.annotation.RegressionTest;
import eu.unicore.util.httpclient.ClientProperties;
import eu.unicore.util.httpclient.HttpUtils;
import eu.unicore.util.httpclient.IClientConfiguration;

public class TestActionBase {

	public static Properties getInsecureProperties() {
		Properties p=new Properties();
		p.put(ClientProperties.DEFAULT_PREFIX + ClientProperties.PROP_SSL_ENABLED, "false");
		p.put(ClientProperties.DEFAULT_PREFIX + ClientProperties.PROP_MESSAGE_SIGNING_ENABLED, "false");
		return p;
	}
	
	@Test
	public void testConfigureHandlers()throws Exception{
		Properties p=getInsecureProperties();
		p.put(ClientProperties.DEFAULT_PREFIX + ClientProperties.PROP_OUT_HANDLERS, "Test123 Test345");
		
		final CommandLine cl=new BasicParser().parse(new Options(), new String[0]);
		ActionBase b=new ActionBase(){
			@Override
			public CommandLine getCommandLine() {
				return cl;
			}
		};
		
		b.setProperties(p);
		b.initSecurityProperties();
		IClientConfiguration sp=b.securityProperties;
		
		assertTrue(sp.getOutHandlerClassNames()[0].equals("Test123"));
		assertTrue(sp.getOutHandlerClassNames()[1].equals("Test345"));
		assertTrue(sp.getETDSettings().isExtendTrustDelegation());
	}
	

	@RegressionTest(url="https://sourceforge.net/tracker/?func=detail&aid=3371018&group_id=102081&atid=633902")
	@Test
	public void testTimeoutParameters()throws Exception{
		ActionBase cmd=(ActionBase)UCC.initCommand(new String[]{"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded"},false);
		cmd.setProperties(getInsecureProperties());
		cmd.initSecurityProperties();
		IClientConfiguration cp=cmd.getClientProperties();
		assertTrue(cp.getExtraSettings().containsKey(HttpUtils.SO_TIMEOUT));
		assertTrue(cp.getExtraSettings().containsKey(HttpUtils.CONNECT_TIMEOUT));
	}

	@Ignore
	@Test
	public void testSecurityPreferencesParsing() throws Exception {
		ActionBase cmd=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "vo:/someVo",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "role:someRole",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "uid:someUid",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "pgid:someGid",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "useOSgids:false",
				"-" + Constants.OPT_SECURITY_PREFERENCES, "supgids:someSupGid1,someSupGid2",
				}, false);
		verifyCommandPref(cmd);

		ActionBase cmd2=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "vo:/someVo",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "role:someRole",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "uid:someUid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "pgid:someGid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "useOSgids:false",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG, "supgids:someSupGid1,someSupGid2",
				}, false);
		verifyCommandPref(cmd2);

		ActionBase cmd3=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs.embedded",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=vo:/someVo",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=role:someRole",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=uid:someUid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=pgid:someGid",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=useOSgids:false",
				"--" + Constants.OPT_SECURITY_PREFERENCES_LONG + "=supgids:someSupGid1,someSupGid2",
				}, false);
		verifyCommandPref(cmd3);
		
		ActionBase cmd4=(ActionBase)UCC.initCommand(new String[]{
				"connect","-r","http://localhost:65322/services/WRONG_SERVICE", 
				"-c", "src/test/resources/conf/userprefs-withSecPrefs.embedded"
				}, false);
		verifyCommandPref(cmd4);
	}
	
	private void verifyCommandPref(ActionBase cmd) throws Exception {
		cmd.setProperties(getInsecureProperties());
		cmd.initSecurityProperties();
		Map<String, String[]> pref = cmd.getClientProperties().getETDSettings().getRequestedUserAttributes2();
		assertEquals("/someVo", pref.get("selectedVirtualOrganisation")[0]);
		assertEquals("someRole", pref.get("role")[0]);
		assertEquals("someUid", pref.get("xlogin")[0]);
		assertEquals("someGid", pref.get("group")[0]);
		assertEquals("false", pref.get("addDefaultGroups")[0]);
		assertEquals("someSupGid1", pref.get("supplementaryGroups")[0]);
		assertEquals("someSupGid2", pref.get("supplementaryGroups")[1]);
	}
}
